##  Role of the Reference Catalog
When a discovered SaaS item is linked to an application fact sheet, it also establishes a link between the fact sheet and the corresponding item in the SAP LeanIX reference catalog. This occurs when:
  * An appropriate reference catalog item exists for that fact sheet
  * The fact sheet isn't already linked to the reference catalog item


Through this connection, information from the reference catalog is automatically synced and updated on relevant application fact sheets. To learn more, see [Applications in the Reference Catalog](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "By using reference data for application fact sheets, you can increase standardization and data quality, as well as set relations to other fact sheets for best-practice modeling.").
